==> beagle-0.0.2.tar.gz: beagle-0.0.2/beagled/DBusisms.cs <==
//
// SearchWindow.cs
//
// Copyright (C) 2004 Novell, Inc.
//

//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
//

using System;
using System.Runtime.InteropServices;

using DBus;

namespace Beagle.Daemon
{
	public class DBusisms {

		static Connection connection = null;
		static Service service = null;
		static BusDriver bus_driver = null;
		static FactoryImpl factory = null;

		public static Connection Connection {
			get { 
				if (connection == null)
					connection = Bus.GetSessionBus ();
				return connection;
			}
		}

		public static Service Service {
			get {
				if (service == null)
					service = new Service (Connection,
							       Beagle.DBusisms.ServiceName);
				return service;
			}
		}

		public static BusDriver BusDriver {
			get {
				if (bus_driver == null)
					bus_driver = BusDriver.New (Connection);
				return bus_driver;
			}
		}

		public static FactoryImpl Factory {
			get {
				return factory;
			}
		}

		[DllImport ("dbus-glib-1")]
		private extern static void dbus_g_thread_init ();

		public static void Init ()
		{
			dbus_g_thread_init ();

			factory = new FactoryImpl ();
			DBusisms.Service.RegisterObject (factory,
							 Beagle.DBusisms.FactoryPath);
		}
				
	}
}

==> beagle-0.0.3.tar.gz: beagle-0.0.3/beagled/DBusisms.cs <==
//
// DBusisms.cs
//
// Copyright (C) 2004 Novell, Inc.
//

//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
//

using System;
using System.Runtime.InteropServices;

using DBus;

namespace Beagle.Daemon
{
	public class DBusisms {

		static Connection connection = null;
		static Service service = null;
		static BusDriver busDriver = null;

		public static Connection Connection {
			get { return connection; }
		}

		public static Service Service {
			get { return service; }
		}

		public static BusDriver BusDriver {
			get { return busDriver; }
		}

		[DllImport ("dbus-glib-1")]
		private extern static void dbus_g_thread_init ();

		public static void Init ()
		{
			if (connection != null)
				return;
					
			dbus_g_thread_init ();
			
			connection = Bus.GetSessionBus ();

			busDriver = BusDriver.New (connection);
		}
		
		public static bool InitService () {
			if (service == null) {
				if (Service.Exists (connection, Beagle.DBusisms.ServiceName)) {
					return false;
				}
				service = new Service (connection, Beagle.DBusisms.ServiceName);
				return true;
			} else {
				return true;
			}
		}
	}
}
